@@ -24,18 +24,18 @@
  *
  * -------------------------------------------------------------------------- */
 
-#include "core/channels/channelManager.h"
-#include "core/channels/channel.h"
-#include "core/channels/channelFactory.h"
-#include "core/midiEvent.h"
-#include "core/mixer.h"
-#include "core/model/model.h"
-#include "core/rendering/midiOutput.h"
-#include "core/rendering/midiReactions.h"
-#include "core/rendering/sampleReactions.h"
-#include "core/waveFactory.h"
-#include "deps/mcl-audio-buffer/src/audioBuffer.hpp"
-#include "utils/log.h"
+#include "src/core/channels/channelManager.h"
+#include "src/core/channels/channel.h"
+#include "src/core/channels/channelFactory.h"
+#include "src/core/midiEvent.h"
+#include "src/core/mixer.h"
+#include "src/core/model/model.h"
+#include "src/core/rendering/midiOutput.h"
+#include "src/core/rendering/midiReactions.h"
+#include "src/core/rendering/sampleReactions.h"
+#include "src/core/waveFactory.h"
+#include "src/deps/mcl-audio-buffer/src/audioBuffer.hpp"
+#include "src/utils/log.h"
 
 namespace giada::m
 {
@@ -74,11 +74,11 @@ void ChannelManager::reset(Frame framesInBuffer)
 	const Resampler::Quality rsmpQuality       = m_model.get().kernelAudio.rsmpQuality;
 
 	channelFactory::Data masterOutData = channelFactory::create(
-	    Mixer::MASTER_OUT_CHANNEL_ID, ChannelType::MASTER, framesInBuffer, rsmpQuality, overdubProtection);
+	    MASTER_OUT_CHANNEL_ID, ChannelType::MASTER, framesInBuffer, rsmpQuality, overdubProtection);
 	channelFactory::Data masterInData = channelFactory::create(
-	    Mixer::MASTER_IN_CHANNEL_ID, ChannelType::MASTER, framesInBuffer, rsmpQuality, overdubProtection);
+	    MASTER_IN_CHANNEL_ID, ChannelType::MASTER, framesInBuffer, rsmpQuality, overdubProtection);
 	channelFactory::Data previewData = channelFactory::create(
-	    Mixer::PREVIEW_CHANNEL_ID, ChannelType::PREVIEW, framesInBuffer, rsmpQuality, overdubProtection);
+	    PREVIEW_CHANNEL_ID, ChannelType::PREVIEW, framesInBuffer, rsmpQuality, overdubProtection);
 
 	m_model.get().tracks = {};
 
@@ -213,11 +213,10 @@ void ChannelManager::cloneChannel(ID channelId, int bufferSize, const std::vecto
 	{
 		const Wave& oldWave  = *oldChannel.sampleChannel->getWave();
 		const Frame oldShift = oldChannel.sampleChannel->shift;
-		const Frame oldBegin = oldChannel.sampleChannel->begin;
-		const Frame oldEnd   = oldChannel.sampleChannel->end;
+		const auto  oldRange = oldChannel.sampleChannel->range;
 		Wave&       wave     = m_model.addWave(waveFactory::createFromWave(oldWave));
 
-		newChannelData.channel.loadWave(&wave, oldBegin, oldEnd, oldShift);
+		newChannelData.channel.loadWave(&wave, oldRange, oldShift);
 	}
 
 	newChannelData.channel.plugins = plugins;
@@ -304,12 +303,12 @@ void ChannelManager::renameChannel(ID channelId, const std::string& name)
 
 float ChannelManager::getMasterInVol() const
 {
-	return m_model.get().tracks.getChannel(Mixer::MASTER_IN_CHANNEL_ID).volume;
+	return m_model.get().tracks.getChannel(MASTER_IN_CHANNEL_ID).volume;
 }
 
 float ChannelManager::getMasterOutVol() const
 {
-	return m_model.get().tracks.getChannel(Mixer::MASTER_OUT_CHANNEL_ID).volume;
+	return m_model.get().tracks.getChannel(MASTER_OUT_CHANNEL_ID).volume;
 }
 
 /* -------------------------------------------------------------------------- */
@@ -348,8 +347,8 @@ void ChannelManager::setPitch(ID channelId, float value)
 
 	const float pitch = std::clamp(value, G_MIN_PITCH, G_MAX_PITCH);
 
-	m_model.get().tracks.getChannel(channelId).sampleChannel->pitch                 = pitch;
-	m_model.get().tracks.getChannel(Mixer::PREVIEW_CHANNEL_ID).sampleChannel->pitch = pitch;
+	m_model.get().tracks.getChannel(channelId).sampleChannel->pitch          = pitch;
+	m_model.get().tracks.getChannel(PREVIEW_CHANNEL_ID).sampleChannel->pitch = pitch;
 	m_model.swap(model::SwapType::SOFT);
 }
 
@@ -363,38 +362,35 @@ void ChannelManager::setPan(ID channelId, float value)
 
 /* -------------------------------------------------------------------------- */
 
-void ChannelManager::setBeginEnd(ID channelId, Frame b, Frame e)
+void ChannelManager::setRange(ID channelId, SampleRange range)
 {
 	Channel& c       = m_model.get().tracks.getChannel(channelId);
-	Channel& preview = m_model.get().tracks.getChannel(Mixer::PREVIEW_CHANNEL_ID);
+	Channel& preview = m_model.get().tracks.getChannel(PREVIEW_CHANNEL_ID);
 
 	assert(c.sampleChannel);
 
-	b = std::clamp(b, 0, c.sampleChannel->getWaveSize() - 1);
-	e = std::clamp(e, 1, c.sampleChannel->getWaveSize());
-	if (b >= e)
-		b = e - 1;
-	else if (e < b)
-		e = b + 1;
+	range.a = std::clamp(range.a, 0, c.sampleChannel->getWaveSize() - 1);
+	range.b = std::clamp(range.b, 1, c.sampleChannel->getWaveSize());
+	if (range.a >= range.b)
+		range.a = range.b - 1;
+	else if (range.b < range.a)
+		range.b = range.a + 1;
 
-	if (c.shared->tracker.load() < b)
-		c.shared->tracker.store(b);
+	if (c.shared->tracker.load() < range.a)
+		c.shared->tracker.store(range.a);
 
-	c.sampleChannel->begin       = b;
-	c.sampleChannel->end         = e;
-	preview.sampleChannel->begin = b;
-	preview.sampleChannel->end   = e;
+	c.sampleChannel->range       = range;
+	preview.sampleChannel->range = range;
 	m_model.swap(model::SwapType::HARD);
 }
 
-void ChannelManager::resetBeginEnd(ID channelId)
+void ChannelManager::resetRange(ID channelId)
 {
 	Channel& c = m_model.get().tracks.getChannel(channelId);
 
 	assert(c.sampleChannel);
 
-	c.sampleChannel->begin = 0;
-	c.sampleChannel->end   = c.sampleChannel->getWaveSize();
+	c.sampleChannel->range = {0, c.sampleChannel->getWaveSize()};
 	m_model.swap(model::SwapType::HARD);
 }
 
@@ -429,7 +425,7 @@ void ChannelManager::setSamplePlayerMode(ID channelId, SamplePlayerMode mode)
 
 /* -------------------------------------------------------------------------- */
 
-void ChannelManager::setHeight(ID channelId, Pixel height)
+void ChannelManager::setHeight(ID channelId, int height)
 {
 	m_model.get().tracks.getChannel(channelId).height = height;
 	m_model.swap(model::SwapType::SOFT);
@@ -437,9 +433,39 @@ void ChannelManager::setHeight(ID channelId, Pixel height)
 
 /* -------------------------------------------------------------------------- */
 
+void ChannelManager::setSendToMaster(ID channelId, bool value)
+{
+	/* Can't toggle 'send to master' flag if there are no extra outputs. */
+	assert(m_model.get().tracks.getChannel(channelId).extraOutputs.size() > 0);
+
+	m_model.get().tracks.getChannel(channelId).sendToMaster = value;
+	m_model.swap(model::SwapType::NONE);
+}
+
+/* -------------------------------------------------------------------------- */
+
+void ChannelManager::addExtraOutput(ID channelId, int offset)
+{
+	/* 'offset' can be only multiple of 2, that is stereo pair. */
+	assert(offset >= 0 && offset % 2 == 0);
+
+	m_model.get().tracks.getChannel(channelId).extraOutputs.push_back(offset);
+	m_model.swap(model::SwapType::HARD);
+}
+
+void ChannelManager::removeExtraOutput(ID channelId, std::size_t i)
+{
+	u::vector::removeAt(m_model.get().tracks.getChannel(channelId).extraOutputs, i);
+	if (m_model.get().tracks.getChannel(channelId).extraOutputs.size() == 0)
+		m_model.get().tracks.getChannel(channelId).sendToMaster = true;
+	m_model.swap(model::SwapType::HARD);
+}
+
+/* -------------------------------------------------------------------------- */
+
 void ChannelManager::loadWaveInPreviewChannel(ID channelId)
 {
-	Channel&       previewCh = m_model.get().tracks.getChannel(Mixer::PREVIEW_CHANNEL_ID);
+	Channel&       previewCh = m_model.get().tracks.getChannel(PREVIEW_CHANNEL_ID);
 	const Channel& sourceCh  = m_model.get().tracks.getChannel(channelId);
 
 	assert(previewCh.sampleChannel);
@@ -447,8 +473,7 @@ void ChannelManager::loadWaveInPreviewChannel(ID channelId)
 
 	previewCh.loadWave(sourceCh.sampleChannel->getWave());
 	previewCh.sampleChannel->mode  = SamplePlayerMode::SINGLE_BASIC_PAUSE;
-	previewCh.sampleChannel->begin = sourceCh.sampleChannel->begin;
-	previewCh.sampleChannel->end   = sourceCh.sampleChannel->end;
+	previewCh.sampleChannel->range = sourceCh.sampleChannel->range;
 	previewCh.sampleChannel->pitch = sourceCh.sampleChannel->pitch;
 
 	m_model.swap(model::SwapType::SOFT);
@@ -458,7 +483,7 @@ void ChannelManager::loadWaveInPreviewChannel(ID channelId)
 
 void ChannelManager::freeWaveInPreviewChannel()
 {
-	Channel& previewCh = m_model.get().tracks.getChannel(Mixer::PREVIEW_CHANNEL_ID);
+	Channel& previewCh = m_model.get().tracks.getChannel(PREVIEW_CHANNEL_ID);
 
 	previewCh.loadWave(nullptr);
 	m_model.swap(model::SwapType::SOFT);
@@ -468,7 +493,7 @@ void ChannelManager::freeWaveInPreviewChannel()
 
 void ChannelManager::setPreviewTracker(Frame f)
 {
-	m_model.get().tracks.getChannel(m::Mixer::PREVIEW_CHANNEL_ID).shared->tracker.store(f);
+	m_model.get().tracks.getChannel(PREVIEW_CHANNEL_ID).shared->tracker.store(f);
 }
 
 /* -------------------------------------------------------------------------- */
@@ -499,7 +524,7 @@ bool ChannelManager::saveSample(ID channelId, const std::string& filePath)
 
 /* -------------------------------------------------------------------------- */
 
-void ChannelManager::consolidateChannels(const std::unordered_set<ID>& ids)
+void ChannelManager::finalizeActionRec(const std::unordered_set<ID>& ids)
 {
 	for (ID id : ids)
 	{
@@ -551,9 +576,9 @@ bool ChannelManager::canRemoveTrack(std::size_t trackIndex) const
 
 /* -------------------------------------------------------------------------- */
 
-void ChannelManager::loadSampleChannel(Channel& ch, Wave* w, Frame begin, Frame end, Frame shift) const
+void ChannelManager::loadSampleChannel(Channel& ch, Wave* w) const
 {
-	ch.loadWave(w, begin, end, shift);
+	ch.loadWave(w);
 	ch.name = w != nullptr ? w->getBasename(/*ext=*/false) : "";
 }
 
@@ -623,7 +648,7 @@ void ChannelManager::recordChannel(Channel& ch, const mcl::AudioBuffer& buffer,
 
 	/* Copy up to wave.getSize() from the mixer's input buffer into wave's. */
 
-	wave->getBuffer().set(buffer, wave->getBuffer().countFrames());
+	wave->getBuffer().setAll(buffer, wave->getBuffer().countFrames(), 0, 0);
 
 	/* Update channel with the new Wave. */
 
@@ -644,7 +669,7 @@ void ChannelManager::overdubChannel(Channel& ch, const mcl::AudioBuffer& buffer,
 
 	model::SharedLock lock = m_model.lockShared();
 
-	wave->getBuffer().sum(buffer, /*gain=*/1.0f);
+	wave->getBuffer().sumAll(buffer);
 	wave->setLogical(true);
 
 	setupChannelPostRecording(ch, currentFrame);
