@@ -24,10 +24,9 @@
  *
  * -------------------------------------------------------------------------- */
 
-#include "core/confFactory.h"
-#include "core/const.h"
-#include "utils/fs.h"
-#include "utils/log.h"
+#include "src/core/confFactory.h"
+#include "src/utils/fs.h"
+#include "src/utils/log.h"
 #include <fstream>
 #include <nlohmann/json.hpp>
 
@@ -35,6 +34,105 @@ namespace giada::m::confFactory
 {
 namespace
 {
+constexpr auto CONF_KEY_HEADER                        = "header";
+constexpr auto CONF_KEY_LOG_MODE                      = "log_mode";
+constexpr auto CONF_KEY_SHOW_TOOLTIPS                 = "show_tooltips";
+constexpr auto CONF_KEY_LANGMAP                       = "langmap";
+constexpr auto CONF_KEY_SOUND_SYSTEM                  = "sound_system";
+constexpr auto CONF_KEY_SOUND_DEVICE_IN               = "sound_device_in";
+constexpr auto CONF_KEY_SOUND_DEVICE_OUT              = "sound_device_out";
+constexpr auto CONF_KEY_CHANNELS_OUT_COUNT            = "channels_out_count";
+constexpr auto CONF_KEY_CHANNELS_OUT_START            = "channels_out_start";
+constexpr auto CONF_KEY_CHANNELS_IN_COUNT             = "channels_in_count";
+constexpr auto CONF_KEY_CHANNELS_IN_START             = "channels_in_start";
+constexpr auto CONF_KEY_SAMPLERATE                    = "samplerate";
+constexpr auto CONF_KEY_BUFFER_SIZE                   = "buffer_size";
+constexpr auto CONF_KEY_LIMIT_OUTPUT                  = "limit_output";
+constexpr auto CONF_KEY_RESAMPLE_QUALITY              = "resample_quality";
+constexpr auto CONF_KEY_MIDI_SYSTEM                   = "midi_system";
+constexpr auto CONF_KEY_MIDI_PORT_OUT                 = "midi_port_out";
+constexpr auto CONF_KEY_MIDI_PORT_IN                  = "midi_port_in";
+constexpr auto CONF_KEY_MIDIMAP_PATH                  = "midimap_path";
+constexpr auto CONF_KEY_MIDI_SYNC                     = "midi_sync";
+constexpr auto CONF_KEY_MIDI_TC_FPS                   = "midi_tc_fps";
+constexpr auto CONF_KEY_MIDI_IN                       = "midi_in";
+constexpr auto CONF_KEY_MIDI_IN_FILTER                = "midi_in_filter";
+constexpr auto CONF_KEY_MIDI_IN_REWIND                = "midi_in_rewind";
+constexpr auto CONF_KEY_MIDI_IN_START_STOP            = "midi_in_start_stop";
+constexpr auto CONF_KEY_MIDI_IN_ACTION_REC            = "midi_in_action_rec";
+constexpr auto CONF_KEY_MIDI_IN_INPUT_REC             = "midi_in_input_rec";
+constexpr auto CONF_KEY_MIDI_IN_METRONOME             = "midi_in_metronome";
+constexpr auto CONF_KEY_MIDI_IN_VOLUME_IN             = "midi_in_volume_in";
+constexpr auto CONF_KEY_MIDI_IN_VOLUME_OUT            = "midi_in_volume_out";
+constexpr auto CONF_KEY_MIDI_IN_BEAT_DOUBLE           = "midi_in_beat_doble";
+constexpr auto CONF_KEY_MIDI_IN_BEAT_HALF             = "midi_in_beat_half";
+constexpr auto CONF_KEY_CHANS_STOP_ON_SEQ_HALT        = "chans_stop_on_seq_halt";
+constexpr auto CONF_KEY_TREAT_RECS_AS_LOOPS           = "treat_recs_as_loops";
+constexpr auto CONF_KEY_INPUT_MONITOR_DEFAULT_ON      = "input_monitor_default_on";
+constexpr auto CONF_KEY_OVERDUB_PROTECTION_DEFAULT_ON = "overdub_protection_default_on";
+constexpr auto CONF_KEY_PLUGINS_PATH                  = "plugins_path";
+constexpr auto CONF_KEY_PATCHES_PATH                  = "patches_path";
+constexpr auto CONF_KEY_SAMPLES_PATH                  = "samples_path";
+constexpr auto CONF_KEY_MAIN_WINDOW_X                 = "main_window_x";
+constexpr auto CONF_KEY_MAIN_WINDOW_Y                 = "main_window_y";
+constexpr auto CONF_KEY_MAIN_WINDOW_W                 = "main_window_w";
+constexpr auto CONF_KEY_MAIN_WINDOW_H                 = "main_window_h";
+constexpr auto CONF_KEY_SETTINGS_WINDOW_X             = "settings_window_x";
+constexpr auto CONF_KEY_SETTINGS_WINDOW_Y             = "settings_window_y";
+constexpr auto CONF_KEY_SETTINGS_WINDOW_W             = "settings_window_w";
+constexpr auto CONF_KEY_SETTINGS_WINDOW_H             = "settings_window_h";
+constexpr auto CONF_KEY_BROWSER_X                     = "browser_x";
+constexpr auto CONF_KEY_BROWSER_Y                     = "browser_y";
+constexpr auto CONF_KEY_BROWSER_W                     = "browser_w";
+constexpr auto CONF_KEY_BROWSER_H                     = "browser_h";
+constexpr auto CONF_KEY_BROWSER_POSITION              = "browser_position";
+constexpr auto CONF_KEY_BROWSER_LAST_PATH             = "browser_last_path";
+constexpr auto CONF_KEY_BROWSER_LAST_VALUE            = "browser_last_value";
+constexpr auto CONF_KEY_ACTION_EDITOR_X               = "action_editor_x";
+constexpr auto CONF_KEY_ACTION_EDITOR_Y               = "action_editor_y";
+constexpr auto CONF_KEY_ACTION_EDITOR_W               = "action_editor_w";
+constexpr auto CONF_KEY_ACTION_EDITOR_H               = "action_editor_h";
+constexpr auto CONF_KEY_ACTION_EDITOR_ZOOM            = "action_editor_zoom";
+constexpr auto CONF_KEY_ACTION_EDITOR_SPLIT_H         = "action_editor_split_h";
+constexpr auto CONF_KEY_ACTION_EDITOR_GRID_VAL        = "action_editor_grid_val";
+constexpr auto CONF_KEY_ACTION_EDITOR_GRID_ON         = "action_editor_grid_on";
+constexpr auto CONF_KEY_SAMPLE_EDITOR_X               = "sample_editor_x";
+constexpr auto CONF_KEY_SAMPLE_EDITOR_Y               = "sample_editor_y";
+constexpr auto CONF_KEY_SAMPLE_EDITOR_W               = "sample_editor_w";
+constexpr auto CONF_KEY_SAMPLE_EDITOR_H               = "sample_editor_h";
+constexpr auto CONF_KEY_SAMPLE_EDITOR_GRID_VAL        = "sample_editor_grid_val";
+constexpr auto CONF_KEY_SAMPLE_EDITOR_GRID_ON         = "sample_editor_grid_on";
+constexpr auto CONF_KEY_ACTION_EDITOR_PIANO_ROLL_Y    = "piano_roll_y";
+constexpr auto CONF_KEY_PLUGIN_LIST_X                 = "plugin_list_x";
+constexpr auto CONF_KEY_PLUGIN_LIST_Y                 = "plugin_list_y";
+constexpr auto CONF_KEY_PLUGIN_LIST_W                 = "plugin_list_w";
+constexpr auto CONF_KEY_PLUGIN_LIST_H                 = "plugin_list_h";
+constexpr auto CONF_KEY_PLUGIN_CHOOSER_X              = "plugin_chooser_x";
+constexpr auto CONF_KEY_PLUGIN_CHOOSER_Y              = "plugin_chooser_y";
+constexpr auto CONF_KEY_PLUGIN_CHOOSER_W              = "plugin_chooser_w";
+constexpr auto CONF_KEY_PLUGIN_CHOOSER_H              = "plugin_chooser_h";
+constexpr auto CONF_KEY_MIDI_INPUT_X                  = "midi_input_x";
+constexpr auto CONF_KEY_MIDI_INPUT_Y                  = "midi_input_y";
+constexpr auto CONF_KEY_MIDI_INPUT_W                  = "midi_input_w";
+constexpr auto CONF_KEY_MIDI_INPUT_H                  = "midi_input_h";
+constexpr auto CONF_KEY_CHANNEL_ROUTING_X             = "channel_routing_x";
+constexpr auto CONF_KEY_CHANNEL_ROUTING_Y             = "channel_routing_y";
+constexpr auto CONF_KEY_CHANNEL_ROUTING_W             = "channel_routing_w";
+constexpr auto CONF_KEY_CHANNEL_ROUTING_H             = "channel_routing_h";
+constexpr auto CONF_KEY_PLUGIN_SORT_METHOD            = "plugin_sort_method";
+constexpr auto CONF_KEY_PLUGIN_SORT_DIR               = "plugin_sort_dir";
+constexpr auto CONF_KEY_REC_TRIGGER_MODE              = "rec_trigger_mode";
+constexpr auto CONF_KEY_REC_TRIGGER_LEVEL             = "rec_trigger_level";
+constexpr auto CONF_KEY_INPUT_REC_MODE                = "input_rec_mode";
+constexpr auto CONF_KEY_BIND_PLAY                     = "key_bind_play";
+constexpr auto CONF_KEY_BIND_REWIND                   = "key_bind_rewind";
+constexpr auto CONF_KEY_BIND_RECORD_ACTIONS           = "key_bind_record_actions";
+constexpr auto CONF_KEY_BIND_RECORD_INPUT             = "key_bind_record_input";
+constexpr auto CONF_KEY_BIND_EXIT                     = "key_bind_record_exit";
+constexpr auto CONF_KEY_UI_SCALING                    = "ui_scaling";
+
+/* -------------------------------------------------------------------------- */
+
 Conf parse_(std::ifstream& ifs)
 {
 	Conf           conf;
@@ -106,6 +204,10 @@ Conf parse_(std::ifstream& ifs)
 	conf.midiInputBounds.y          = j.value(CONF_KEY_MIDI_INPUT_Y, conf.midiInputBounds.y);
 	conf.midiInputBounds.w          = j.value(CONF_KEY_MIDI_INPUT_W, conf.midiInputBounds.w);
 	conf.midiInputBounds.h          = j.value(CONF_KEY_MIDI_INPUT_H, conf.midiInputBounds.h);
+	conf.channelRoutingBounds.x     = j.value(CONF_KEY_CHANNEL_ROUTING_X, conf.channelRoutingBounds.x);
+	conf.channelRoutingBounds.y     = j.value(CONF_KEY_CHANNEL_ROUTING_Y, conf.channelRoutingBounds.y);
+	conf.channelRoutingBounds.w     = j.value(CONF_KEY_CHANNEL_ROUTING_W, conf.channelRoutingBounds.w);
+	conf.channelRoutingBounds.h     = j.value(CONF_KEY_CHANNEL_ROUTING_H, conf.channelRoutingBounds.h);
 	conf.recTriggerMode             = j.value(CONF_KEY_REC_TRIGGER_MODE, conf.recTriggerMode);
 	conf.recTriggerLevel            = j.value(CONF_KEY_REC_TRIGGER_LEVEL, conf.recTriggerLevel);
 	conf.inputRecMode               = j.value(CONF_KEY_INPUT_REC_MODE, conf.inputRecMode);
@@ -145,7 +247,7 @@ void sanitize_(Conf& conf)
 {
 	conf.soundDeviceOut   = std::max(0, conf.soundDeviceOut);
 	conf.soundDeviceIn    = std::max(0, conf.soundDeviceIn);
-	conf.channelsOutCount = G_MAX_IO_CHANS;
+	conf.channelsOutCount = std::max(0, conf.channelsOutCount);
 	conf.channelsOutStart = std::max(0, conf.channelsOutStart);
 	conf.channelsInCount  = std::max(1, conf.channelsInCount);
 	conf.channelsInStart  = std::max(0, conf.channelsInStart);
@@ -242,6 +344,10 @@ bool serialize(const Conf& conf)
 	j[CONF_KEY_MIDI_INPUT_Y]                  = conf.midiInputBounds.y;
 	j[CONF_KEY_MIDI_INPUT_W]                  = conf.midiInputBounds.w;
 	j[CONF_KEY_MIDI_INPUT_H]                  = conf.midiInputBounds.h;
+	j[CONF_KEY_CHANNEL_ROUTING_X]             = conf.channelRoutingBounds.x;
+	j[CONF_KEY_CHANNEL_ROUTING_Y]             = conf.channelRoutingBounds.y;
+	j[CONF_KEY_CHANNEL_ROUTING_W]             = conf.channelRoutingBounds.w;
+	j[CONF_KEY_CHANNEL_ROUTING_H]             = conf.channelRoutingBounds.h;
 	j[CONF_KEY_REC_TRIGGER_MODE]              = static_cast<int>(conf.recTriggerMode);
 	j[CONF_KEY_REC_TRIGGER_LEVEL]             = conf.recTriggerLevel;
 	j[CONF_KEY_INPUT_REC_MODE]                = static_cast<int>(conf.inputRecMode);
