@@ -27,14 +27,14 @@
 #ifdef __APPLE__
 #include <pwd.h>
 #endif
-#include "core/confFactory.h"
-#include "core/engine.h"
-#include "gui/elems/mainWindow/keyboard/keyboard.h"
-#include "gui/elems/mainWindow/mainInput.h"
-#include "gui/elems/mainWindow/mainOutput.h"
-#include "gui/ui.h"
-#include "utils/log.h"
-#include "utils/ver.h"
+#include "src/core/confFactory.h"
+#include "src/core/engine.h"
+#include "src/gui/elems/mainWindow/keyboard/keyboard.h"
+#include "src/gui/elems/mainWindow/mainInput.h"
+#include "src/gui/elems/mainWindow/mainOutput.h"
+#include "src/gui/ui.h"
+#include "src/utils/log.h"
+#include "src/utils/ver.h"
 #ifdef WITH_TESTS
 #define CATCH_CONFIG_RUNNER
 #include "tests/actionRecorder.cpp"
@@ -44,6 +44,7 @@
 #include "tests/patch.cpp"
 #include "tests/sampleRendering.cpp"
 #include "tests/utils.cpp"
+#include "tests/version.cpp"
 #include "tests/wave.cpp"
 #include "tests/waveFactory.cpp"
 #include "tests/waveFx.cpp"
@@ -63,9 +64,9 @@ namespace
 {
 void printBuildInfo_()
 {
-	u::log::print("[init] Giada {}\n", G_VERSION_STR);
+	u::log::print("[init] Giada {}\n", G_VERSION.toString());
 	u::log::print("[init] Build date: " BUILD_DATE "\n");
-#ifdef G_DEBUG_MODE
+#if G_DEBUG_MODE
 	u::log::print("[init] Debug build\n");
 #else
 	u::log::print("[init] Release build\n");
@@ -179,7 +180,7 @@ void shutdown()
 	else
 		u::log::print("[init::shutdown] configuration saved\n");
 
-	u::log::print("[init] Giada {} closed\n\n", G_VERSION_STR);
+	u::log::print("[init] Giada {} closed\n\n", G_VERSION.toString());
 	u::log::close();
 }
 } // namespace giada::m::init
