@@ -24,9 +24,8 @@
  *
  * -------------------------------------------------------------------------- */
 
-#include "wave.h"
-#include "const.h"
-#include "utils/fs.h"
+#include "src/core/wave.h"
+#include "src/utils/fs.h"
 #include <cassert>
 #include <fmt/core.h>
 
