@@ -27,7 +27,7 @@
 #ifndef GE_MIDI_CHANNEL_BUTTON_H
 #define GE_MIDI_CHANNEL_BUTTON_H
 
-#include "channelButton.h"
+#include "src/gui/elems/mainWindow/keyboard/channelButton.h"
 
 namespace giada::v
 {
