@@ -24,9 +24,9 @@
  *
  * -------------------------------------------------------------------------- */
 
-#include "gui/langMapper.h"
-#include "utils/fs.h"
-#include "utils/log.h"
+#include "src/gui/langMapper.h"
+#include "src/utils/fs.h"
+#include "src/utils/log.h"
 #include <filesystem>
 #include <fstream>
 
@@ -222,7 +222,7 @@ LangMap::LangMap()
 	m_data[SAMPLEEDITOR_TOOLS_FADE_IN]        = "Fade in";
 	m_data[SAMPLEEDITOR_TOOLS_FADE_OUT]       = "Fade out";
 	m_data[SAMPLEEDITOR_TOOLS_SMOOTH_EDGES]   = "Smooth edges";
-	m_data[SAMPLEEDITOR_TOOLS_SET_BEGIN_END]  = "Set begin/end here";
+	m_data[SAMPLEEDITOR_TOOLS_SET_RANGE]      = "Set begin/end here";
 	m_data[SAMPLEEDITOR_TOOLS_TO_NEW_CHANNEL] = "Copy to new channel";
 
 	m_data[ACTIONEDITOR_TITLE]            = "Action Editor";
@@ -290,12 +290,13 @@ LangMap::LangMap()
 	m_data[CONFIG_AUDIO_TITLE]                 = "Audio";
 	m_data[CONFIG_AUDIO_SYSTEM]                = "System";
 	m_data[CONFIG_AUDIO_BUFFERSIZE]            = "Buffer size";
+	m_data[CONFIG_AUDIO_TOTALOUTPUTCHANNELS]   = "Total output channels";
 	m_data[CONFIG_AUDIO_SAMPLERATE]            = "Sample rate";
 	m_data[CONFIG_AUDIO_OUTPUTDEVICE]          = "Output device";
-	m_data[CONFIG_AUDIO_OUTPUTCHANNELS]        = "Output channels";
+	m_data[CONFIG_AUDIO_OUTPUTCHANNELS]        = "Master out channels";
 	m_data[CONFIG_AUDIO_LIMITOUTPUT]           = "Limit output";
 	m_data[CONFIG_AUDIO_INPUTDEVICE]           = "Input device";
-	m_data[CONFIG_AUDIO_INPUTCHANNELS]         = "Input channels";
+	m_data[CONFIG_AUDIO_INPUTCHANNELS]         = "Master in channels";
 	m_data[CONFIG_AUDIO_RECTHRESHOLD]          = "Rec threshold (dB)";
 	m_data[CONFIG_AUDIO_ENABLEINPUT]           = "Enable Input";
 	m_data[CONFIG_AUDIO_RESAMPLING]            = "Resampling";
@@ -348,7 +349,12 @@ LangMap::LangMap()
 	m_data[CONFIG_PLUGINS_SCAN]        = "Scan ({} found)";
 	m_data[CONFIG_PLUGINS_INVALIDPATH] = "Invalid path.";
 
-	m_data[CHANNELROUTING_TITLE] = "Channel Routing";
+	m_data[CHANNELROUTING_TITLE]              = "Channel Routing";
+	m_data[CHANNELROUTING_SENDTOMASTEROUT]    = "Send to master output channel";
+	m_data[CHANNELROUTING_SENDTOPARENTGROUP]  = "Send to parent group";
+	m_data[CHANNELROUTING_ADDNEWOUTPUT]       = "Add new audio output";
+	m_data[CHANNELROUTING_OUTPUT_CHOOSE]      = "(choose)";
+	m_data[CHANNELROUTING_OUTPUT_UNREACHABLE] = "(unreachable)";
 }
 
 const char* LangMap::get(const std::string& key) const
